==> openshift-model-config-6.8.1-sources.jar: io/fabric8/openshift/api/model/config/v1/ConsoleSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsoleSpecFluent<A extends ConsoleSpecFluent<A>> extends BaseFluent<A>{
  public ConsoleSpecFluent() {
  }
  public ConsoleSpecFluent(ConsoleSpec instance) {
    instance = (instance != null ? instance : new ConsoleSpec());

    if (instance != null) {
      this.withAuthentication(instance.getAuthentication());
      this.withAuthentication(instance.getAuthentication());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ConsoleAuthenticationBuilder authentication;
  private Map<String,Object> additionalProperties;
  public ConsoleAuthentication buildAuthentication() {
    return this.authentication!=null ?this.authentication.build():null;
  }
  public A withAuthentication(ConsoleAuthentication authentication) {
    _visitables.get("authentication").remove(this.authentication);
    if (authentication!=null){ this.authentication= new ConsoleAuthenticationBuilder(authentication); _visitables.get("authentication").add(this.authentication);} else { this.authentication = null; _visitables.get("authentication").remove(this.authentication); } return (A) this;
  }
  public boolean hasAuthentication() {
    return this.authentication != null;
  }
  public A withNewAuthentication(String logoutRedirect) {
    return (A)withAuthentication(new ConsoleAuthentication(logoutRedirect));
  }
  public AuthenticationNested<A> withNewAuthentication() {
    return new AuthenticationNested(null);
  }
  public AuthenticationNested<A> withNewAuthenticationLike(ConsoleAuthentication item) {
    return new AuthenticationNested(item);
  }
  public AuthenticationNested<A> editAuthentication() {
    return withNewAuthenticationLike(java.util.Optional.ofNullable(buildAuthentication()).orElse(null));
  }
  public AuthenticationNested<A> editOrNewAuthentication() {
    return withNewAuthenticationLike(java.util.Optional.ofNullable(buildAuthentication()).orElse(new ConsoleAuthenticationBuilder().build()));
  }
  public AuthenticationNested<A> editOrNewAuthenticationLike(ConsoleAuthentication item) {
    return withNewAuthenticationLike(java.util.Optional.ofNullable(buildAuthentication()).orElse(item));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleSpecFluent that = (ConsoleSpecFluent) o;
    if (!java.util.Objects.equals(authentication, that.authentication)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(authentication,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (authentication != null) { sb.append("authentication:"); sb.append(authentication + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class AuthenticationNested<N> extends ConsoleAuthenticationFluent<AuthenticationNested<N>> implements Nested<N>{
    AuthenticationNested(ConsoleAuthentication item) {
      this.builder = new ConsoleAuthenticationBuilder(this, item);
    }
    ConsoleAuthenticationBuilder builder;
    public N and() {
      return (N) ConsoleSpecFluent.this.withAuthentication(builder.build());
    }
    public N endAuthentication() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.9.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ConsoleSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ConsoleSpecFluent<A extends ConsoleSpecFluent<A>> extends BaseFluent<A>{
  public ConsoleSpecFluent() {
  }
  
  public ConsoleSpecFluent(ConsoleSpec instance) {
    this.copyInstance(instance);
  }
  private ConsoleAuthenticationBuilder authentication;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ConsoleSpec instance) {
    instance = (instance != null ? instance : new ConsoleSpec());
  
    if (instance != null) {
        this.withAuthentication(instance.getAuthentication());
        this.withAuthentication(instance.getAuthentication());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public ConsoleAuthentication buildAuthentication() {
    return this.authentication!=null ?this.authentication.build():null;
  }
  
  public A withAuthentication(ConsoleAuthentication authentication) {
    _visitables.get("authentication").remove(this.authentication);
    if (authentication!=null){ this.authentication= new ConsoleAuthenticationBuilder(authentication); _visitables.get("authentication").add(this.authentication);} else { this.authentication = null; _visitables.get("authentication").remove(this.authentication); } return (A) this;
  }
  
  public boolean hasAuthentication() {
    return this.authentication != null;
  }
  
  public A withNewAuthentication(String logoutRedirect) {
    return (A)withAuthentication(new ConsoleAuthentication(logoutRedirect));
  }
  
  public AuthenticationNested<A> withNewAuthentication() {
    return new AuthenticationNested(null);
  }
  
  public AuthenticationNested<A> withNewAuthenticationLike(ConsoleAuthentication item) {
    return new AuthenticationNested(item);
  }
  
  public AuthenticationNested<A> editAuthentication() {
    return withNewAuthenticationLike(java.util.Optional.ofNullable(buildAuthentication()).orElse(null));
  }
  
  public AuthenticationNested<A> editOrNewAuthentication() {
    return withNewAuthenticationLike(java.util.Optional.ofNullable(buildAuthentication()).orElse(new ConsoleAuthenticationBuilder().build()));
  }
  
  public AuthenticationNested<A> editOrNewAuthenticationLike(ConsoleAuthentication item) {
    return withNewAuthenticationLike(java.util.Optional.ofNullable(buildAuthentication()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleSpecFluent that = (ConsoleSpecFluent) o;
    if (!java.util.Objects.equals(authentication, that.authentication)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(authentication,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (authentication != null) { sb.append("authentication:"); sb.append(authentication + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class AuthenticationNested<N> extends ConsoleAuthenticationFluent<AuthenticationNested<N>> implements Nested<N>{
    AuthenticationNested(ConsoleAuthentication item) {
      this.builder = new ConsoleAuthenticationBuilder(this, item);
    }
    ConsoleAuthenticationBuilder builder;
    
    public N and() {
      return (N) ConsoleSpecFluent.this.withAuthentication(builder.build());
    }
    
    public N endAuthentication() {
      return and();
    }
    
  
  }

}
